@@ -23,7 +23,7 @@
 #'   default).
 #' @param transform A character value indicating whether the training samples
 #'   are transformed. If the time series has a trend it is recommended. By
-#'   default is \code{"multiplicative"} (multiplicative transformation). It is also
+#'   default is \code{"additive"} (additive transformation). It is also
 #'   possible a multiplicative transformation or no transformation.
 #' @return An object of class \code{"grnnForecast"}. The function
 #'   \code{\link[base]{summary}} can be used to obtain or print a summary of the
@@ -41,7 +41,7 @@
 #' @export
 grnn_forecasting <- function(timeS, h, lags = NULL, sigma = "ROLLING",
                             msas = c("recursive", "MIMO"),
-                            transform = c("multiplicative", "additive", "none")) {
+                            transform = c("additive", "multiplicative", "none")) {
   # Check timeS parameter
   stopifnot(stats::is.ts(timeS) || is.vector(timeS, mode = "numeric"))
   if (! stats::is.ts(timeS))
